@@ -31,7 +31,9 @@ import (
 	"sync"
 	"time"
 
+	"github.com/google/uuid"
 	"github.com/invopop/jsonschema"
+	"github.com/sirupsen/logrus"
 	"google.golang.org/protobuf/encoding/protojson"
 	"google.golang.org/protobuf/protoadapt"
 	"google.golang.org/protobuf/runtime/protoiface"
@@ -97,6 +99,7 @@ func InterruptableRPC[T any](
 
 			return
 		}
+
 		resCh <- res
 	}()
 
@@ -209,12 +212,12 @@ func loadContainerConfig(path string) (*pb.ContainerConfig, error) {
 		return nil, err
 	}
 
-	if config.Metadata == nil {
+	if config.GetMetadata() == nil {
 		return nil, errors.New("metadata is not set")
 	}
 
-	if config.Metadata.Name == "" {
-		return nil, fmt.Errorf("name is not in metadata %q", config.Metadata)
+	if config.GetMetadata().GetName() == "" {
+		return nil, fmt.Errorf("name is not in metadata %q", config.GetMetadata())
 	}
 
 	return &config, nil
@@ -245,12 +248,20 @@ func loadPodSandboxConfig(path string) (*pb.PodSandboxConfig, error) {
 		return nil, err
 	}
 
-	if config.Metadata == nil {
+	if config.GetMetadata() == nil {
 		return nil, errors.New("metadata is not set")
 	}
 
-	if config.Metadata.Name == "" || config.Metadata.Namespace == "" || config.Metadata.Uid == "" {
-		return nil, fmt.Errorf("name, namespace or uid is not in metadata %q", config.Metadata)
+	if config.GetMetadata().GetUid() == "" {
+		config.Metadata.Uid = uuid.New().String()
+	}
+
+	if config.GetMetadata().GetName() == "" || config.GetMetadata().GetNamespace() == "" {
+		return nil, fmt.Errorf("name or namespace is not in metadata %q", config.GetMetadata())
+	}
+
+	if config.GetLinux() != nil && config.GetLinux().GetCgroupParent() == "" {
+		logrus.Warn("cgroup_parent is not set. Use `runtime-config` to get the runtime cgroup driver")
 	}
 
 	return &config, nil
@@ -478,7 +489,7 @@ func parseLabelStringSlice(ss []string) (map[string]string, error) {
 
 // marshalMapInOrder marshals a map into JSON in the order of the original
 // data structure.
-func marshalMapInOrder(m map[string]interface{}, t interface{}) (string, error) {
+func marshalMapInOrder(m map[string]any, t any) (string, error) {
 	s := "{"
 
 	v := reflect.ValueOf(t)
@@ -546,37 +557,37 @@ func matchesRegex(pattern, target string) bool {
 	return matched
 }
 
-func matchesImage(imageClient internalapi.ImageManagerService, image, containerImage string) (bool, error) {
+func matchesImage(ctx context.Context, imageClient internalapi.ImageManagerService, image, containerImage string) (bool, error) {
 	if image == "" || imageClient == nil {
 		return true, nil
 	}
 
-	r1, err := ImageStatus(imageClient, image, false)
+	r1, err := ImageStatus(ctx, imageClient, image, false)
 	if err != nil {
 		return false, err
 	}
 
-	r2, err := ImageStatus(imageClient, containerImage, false)
+	r2, err := ImageStatus(ctx, imageClient, containerImage, false)
 	if err != nil {
 		return false, err
 	}
 
-	if r1.Image == nil || r2.Image == nil {
+	if r1.GetImage() == nil || r2.GetImage() == nil {
 		// Always return not match if the image doesn't exist.
 		return false, nil
 	}
 
-	return r1.Image.Id == r2.Image.Id, nil
+	return r1.GetImage().GetId() == r2.GetImage().GetId(), nil
 }
 
-func getRepoImage(imageClient internalapi.ImageManagerService, image string) (string, error) {
-	r, err := ImageStatus(imageClient, image, false)
+func getRepoImage(ctx context.Context, imageClient internalapi.ImageManagerService, image string) (string, error) {
+	r, err := ImageStatus(ctx, imageClient, image, false)
 	if err != nil {
 		return "", err
 	}
 
-	if len(r.Image.RepoTags) > 0 {
-		return r.Image.RepoTags[0], nil
+	if len(r.GetImage().GetRepoTags()) > 0 {
+		return r.GetImage().GetRepoTags()[0], nil
 	}
 
 	return image, nil
